@@ -16,7 +16,6 @@
 
 #include <KAboutData>
 #include <KLocalizedString>
-#include <KIdleTime>
 #ifdef RESTORE_NOTIFICATIONS
 #include <KConfigGroup>
 #include <KConfigGui>
@@ -160,7 +159,7 @@ MessageNotification::MessageNotification(const KAEvent& event, const KAAlarm& al
     if (!(flags & NoInitView))
         MessageNotification::setUpDisplay();    // avoid calling virtual method from constructor
 
-    connect(this, qOverload<unsigned int>(&KNotification::activated), this, &MessageNotification::buttonActivated);
+    connect(this, &KNotification::activated, this, &MessageNotification::buttonActivated);
     connect(this, &KNotification::closed, this, &MessageNotification::slotClosed);
     connect(mHelper, &MessageDisplayHelper::textsChanged, this, &MessageNotification::textsChanged);
     connect(mHelper, &MessageDisplayHelper::commandExited, this, &MessageNotification::commandCompleted);
@@ -183,7 +182,7 @@ MessageNotification::MessageNotification(const KAEvent& event, const DateTime& a
     setWidget(MainWindow::mainMainWindow());
     MessageNotification::setUpDisplay();    // avoid calling virtual method from constructor
 
-    connect(this, qOverload<unsigned int>(&KNotification::activated), this, &MessageNotification::buttonActivated);
+    connect(this, &KNotification::activated, this, &MessageNotification::buttonActivated);
     connect(this, &KNotification::closed, this, &MessageNotification::slotClosed);
     connect(mHelper, &MessageDisplayHelper::textsChanged, this, &MessageNotification::textsChanged);
 
@@ -203,7 +202,7 @@ MessageNotification::MessageNotification(const QString& eventId, MessageDisplayH
     MNSessionManager::create();
     setWidget(MainWindow::mainMainWindow());
 
-    connect(this, qOverload<unsigned int>(&KNotification::activated), this, &MessageNotification::buttonActivated);
+    connect(this, &KNotification::activated, this, &MessageNotification::buttonActivated);
     connect(this, &KNotification::closed, this, &MessageNotification::slotClosed);
     connect(mHelper, &MessageDisplayHelper::textsChanged, this, &MessageNotification::textsChanged);
     connect(mHelper, &MessageDisplayHelper::commandExited, this, &MessageNotification::commandCompleted);
@@ -360,7 +359,7 @@ void MessageNotification::showDisplay()
             mShown = true;
             // Ensure that the screen wakes from sleep, in case the window manager
             // doesn't do this when the notification is displayed.
-            KIdleTime::instance()->simulateUserActivity();
+            mHelper->wakeScreen();
         }
         if (!mDisplayComplete  &&  !mErrorWindow()  &&  mAlarmType() != KAAlarm::INVALID_ALARM)
             mHelper->displayComplete(false);   // reschedule
